"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.partitionSourceFiles = exports.createProject = void 0;
const node_path_1 = __importDefault(require("node:path"));
const ts_morph_1 = require("ts-morph");
const resolvePaths = (cwd, patterns) => {
    return [patterns].flat().map(pattern => {
        if (pattern.startsWith('!'))
            return '!' + node_path_1.default.join(cwd, pattern.slice(1));
        return node_path_1.default.join(cwd, pattern);
    });
};
const createProject = async (configuration, paths) => {
    const { tsConfigFilePath, workingDir } = configuration;
    const tsConfig = tsConfigFilePath ? { tsConfigFilePath } : { compilerOptions: { allowJs: true } };
    const workspace = new ts_morph_1.Project({
        ...tsConfig,
        skipAddingFilesFromTsConfig: true,
        skipFileDependencyResolution: true,
    });
    if (paths)
        workspace.addSourceFilesAtPaths(resolvePaths(workingDir, paths));
    return workspace;
};
exports.createProject = createProject;
const partitionSourceFiles = (projectFiles, productionFiles) => {
    const productionFilePaths = productionFiles.map(file => file.getFilePath());
    const usedFiles = [];
    const unusedFiles = [];
    projectFiles.forEach(projectFile => {
        if (productionFilePaths.includes(projectFile.getFilePath())) {
            usedFiles.push(projectFile);
        }
        else {
            unusedFiles.push(projectFile);
        }
    });
    return [usedFiles, unusedFiles];
};
exports.partitionSourceFiles = partitionSourceFiles;
